from ..broker import Broker


class DeviceZoneBroker(Broker):
    controller = "device_zones"

    def show(self, **kwargs):
        """Shows the details for the specified device zone.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device zone methods. The listed methods will be called on each device zone returned and included in the output. Available methods are: zone_interface, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: zone_interface, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_zone: The device zone identified by the specified DeviceZoneID.
             :rtype device_zone: DeviceZone

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device zones. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which this zone belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device zone methods. The listed methods will be called on each device zone returned and included in the output. Available methods are: zone_interface, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: zone_interface, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceZoneID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceZoneID. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceZone. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_zones: An array of the DeviceZone objects that match the specified input criteria.
             :rtype device_zones: Array of DeviceZone

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device zones matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which this zone belongs.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneArtificialInd: A flag indicating that this zone has no counterpart in the device configuration.
             :type ZoneArtificialInd: Array of Boolean

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type ZoneChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneEndTime: The ending effective time of this record, or empty if still in effect.
             :type ZoneEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneFirstSeenTime: The timestamp of when NetMRI first discovered this service.
             :type ZoneFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneInterfaceCount: The total number of interfaces connected to this zone.
             :type ZoneInterfaceCount: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneInterfaceID: The internal NetMRI identifier of that interface, if only one interface connected to this zone.
             :type ZoneInterfaceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneName: The name of the zone.
             :type ZoneName: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneProvisionData: Internal data - do not modify, may change without warning.
             :type ZoneProvisionData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneStartTime: The starting effective time of this record.
             :type ZoneStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ZoneTimestamp: The date and time this record was collected or calculated.
             :type ZoneTimestamp: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device zone methods. The listed methods will be called on each device zone returned and included in the output. Available methods are: zone_interface, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: zone_interface, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceZoneID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceZoneID. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceZone. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device zones, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, DeviceZoneID, ZoneArtificialInd, ZoneChangedCols, ZoneEndTime, ZoneFirstSeenTime, ZoneInterfaceCount, ZoneInterfaceID, ZoneName, ZoneProvisionData, ZoneStartTime, ZoneTimestamp.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_zones: An array of the DeviceZone objects that match the specified input criteria.
             :rtype device_zones: Array of DeviceZone

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device zones matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, DeviceZoneID, ZoneArtificialInd, ZoneChangedCols, ZoneEndTime, ZoneFirstSeenTime, ZoneInterfaceCount, ZoneInterfaceID, ZoneName, ZoneProvisionData, ZoneStartTime, ZoneTimestamp.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device to which this zone belongs. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceZoneID: The operator to apply to the field DeviceZoneID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceZoneID: The internal NetMRI identifier for this filtering zone. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceZoneID: If op_DeviceZoneID is specified, the field named in this input will be compared to the value in DeviceZoneID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceZoneID must be specified if op_DeviceZoneID is specified.
             :type val_f_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceZoneID: If op_DeviceZoneID is specified, this value will be compared to the value in DeviceZoneID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceZoneID must be specified if op_DeviceZoneID is specified.
             :type val_c_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneArtificialInd: The operator to apply to the field ZoneArtificialInd. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneArtificialInd: A flag indicating that this zone has no counterpart in the device configuration. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneArtificialInd: If op_ZoneArtificialInd is specified, the field named in this input will be compared to the value in ZoneArtificialInd using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneArtificialInd must be specified if op_ZoneArtificialInd is specified.
             :type val_f_ZoneArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneArtificialInd: If op_ZoneArtificialInd is specified, this value will be compared to the value in ZoneArtificialInd using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneArtificialInd must be specified if op_ZoneArtificialInd is specified.
             :type val_c_ZoneArtificialInd: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneChangedCols: The operator to apply to the field ZoneChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneChangedCols: If op_ZoneChangedCols is specified, the field named in this input will be compared to the value in ZoneChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneChangedCols must be specified if op_ZoneChangedCols is specified.
             :type val_f_ZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneChangedCols: If op_ZoneChangedCols is specified, this value will be compared to the value in ZoneChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneChangedCols must be specified if op_ZoneChangedCols is specified.
             :type val_c_ZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneEndTime: The operator to apply to the field ZoneEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneEndTime: If op_ZoneEndTime is specified, the field named in this input will be compared to the value in ZoneEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneEndTime must be specified if op_ZoneEndTime is specified.
             :type val_f_ZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneEndTime: If op_ZoneEndTime is specified, this value will be compared to the value in ZoneEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneEndTime must be specified if op_ZoneEndTime is specified.
             :type val_c_ZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneFirstSeenTime: The operator to apply to the field ZoneFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneFirstSeenTime: The timestamp of when NetMRI first discovered this service. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneFirstSeenTime: If op_ZoneFirstSeenTime is specified, the field named in this input will be compared to the value in ZoneFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneFirstSeenTime must be specified if op_ZoneFirstSeenTime is specified.
             :type val_f_ZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneFirstSeenTime: If op_ZoneFirstSeenTime is specified, this value will be compared to the value in ZoneFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneFirstSeenTime must be specified if op_ZoneFirstSeenTime is specified.
             :type val_c_ZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneInterfaceCount: The operator to apply to the field ZoneInterfaceCount. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneInterfaceCount: The total number of interfaces connected to this zone. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneInterfaceCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneInterfaceCount: If op_ZoneInterfaceCount is specified, the field named in this input will be compared to the value in ZoneInterfaceCount using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneInterfaceCount must be specified if op_ZoneInterfaceCount is specified.
             :type val_f_ZoneInterfaceCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneInterfaceCount: If op_ZoneInterfaceCount is specified, this value will be compared to the value in ZoneInterfaceCount using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneInterfaceCount must be specified if op_ZoneInterfaceCount is specified.
             :type val_c_ZoneInterfaceCount: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneInterfaceID: The operator to apply to the field ZoneInterfaceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneInterfaceID: The internal NetMRI identifier of that interface, if only one interface connected to this zone. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneInterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneInterfaceID: If op_ZoneInterfaceID is specified, the field named in this input will be compared to the value in ZoneInterfaceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneInterfaceID must be specified if op_ZoneInterfaceID is specified.
             :type val_f_ZoneInterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneInterfaceID: If op_ZoneInterfaceID is specified, this value will be compared to the value in ZoneInterfaceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneInterfaceID must be specified if op_ZoneInterfaceID is specified.
             :type val_c_ZoneInterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneName: The operator to apply to the field ZoneName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneName: The name of the zone. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneName: If op_ZoneName is specified, the field named in this input will be compared to the value in ZoneName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneName must be specified if op_ZoneName is specified.
             :type val_f_ZoneName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneName: If op_ZoneName is specified, this value will be compared to the value in ZoneName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneName must be specified if op_ZoneName is specified.
             :type val_c_ZoneName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneProvisionData: The operator to apply to the field ZoneProvisionData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneProvisionData: Internal data - do not modify, may change without warning. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneProvisionData: If op_ZoneProvisionData is specified, the field named in this input will be compared to the value in ZoneProvisionData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneProvisionData must be specified if op_ZoneProvisionData is specified.
             :type val_f_ZoneProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneProvisionData: If op_ZoneProvisionData is specified, this value will be compared to the value in ZoneProvisionData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneProvisionData must be specified if op_ZoneProvisionData is specified.
             :type val_c_ZoneProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneStartTime: The operator to apply to the field ZoneStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneStartTime: If op_ZoneStartTime is specified, the field named in this input will be compared to the value in ZoneStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneStartTime must be specified if op_ZoneStartTime is specified.
             :type val_f_ZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneStartTime: If op_ZoneStartTime is specified, this value will be compared to the value in ZoneStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneStartTime must be specified if op_ZoneStartTime is specified.
             :type val_c_ZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ZoneTimestamp: The operator to apply to the field ZoneTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ZoneTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ZoneTimestamp: If op_ZoneTimestamp is specified, the field named in this input will be compared to the value in ZoneTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ZoneTimestamp must be specified if op_ZoneTimestamp is specified.
             :type val_f_ZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ZoneTimestamp: If op_ZoneTimestamp is specified, this value will be compared to the value in ZoneTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ZoneTimestamp must be specified if op_ZoneTimestamp is specified.
             :type val_c_ZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device zone methods. The listed methods will be called on each device zone returned and included in the output. Available methods are: zone_interface, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: zone_interface, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceZoneID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceZoneID. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceZone. Valid values are DeviceZoneID, DeviceID, DataSourceID, ZoneFirstSeenTime, ZoneStartTime, ZoneEndTime, ZoneTimestamp, ZoneChangedCols, ZoneName, ZoneProvisionData, ZoneInterfaceCount, ZoneInterfaceID, ZoneArtificialInd. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_zones: An array of the DeviceZone objects that match the specified input criteria.
             :rtype device_zones: Array of DeviceZone

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def zone_interface(self, **kwargs):
        """The Interface linked to this zone (if only one interface linked to this zone)

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The Interface linked to this zone (if only one interface linked to this zone)
             :rtype : Interface

            """

        return self.api_request(self._get_method_fullname("zone_interface"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier for this filtering zone.
             :type DeviceZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..remote import RemoteModel


class DeviceViewerRouterBgpGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``DeviceID:`` none
    |  ``attribute type:`` string

    |  ``BGPLocalIPDotted:`` none
    |  ``attribute type:`` string

    |  ``BGPLocalIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``BGPLocalPort:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkID:`` none
    |  ``attribute type:`` string

    |  ``Network:`` none
    |  ``attribute type:`` string

    |  ``RPPeerIPDotted:`` none
    |  ``attribute type:`` string

    |  ``RPPeerIPNumeric:`` none
    |  ``attribute type:`` string

    |  ``BGPPeerPort:`` none
    |  ``attribute type:`` string

    |  ``RoutingAreaNumber:`` none
    |  ``attribute type:`` string

    |  ``RPPeerDeviceName:`` none
    |  ``attribute type:`` string

    |  ``RPPeerDeviceID:`` none
    |  ``attribute type:`` string

    |  ``RPPeerDeviceType:`` none
    |  ``attribute type:`` string

    |  ``RPPeerState:`` none
    |  ``attribute type:`` string

    |  ``RPPeerUpSince:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "DeviceID",
                  "BGPLocalIPDotted",
                  "BGPLocalIPNumeric",
                  "BGPLocalPort",
                  "VirtualNetworkID",
                  "Network",
                  "RPPeerIPDotted",
                  "RPPeerIPNumeric",
                  "BGPPeerPort",
                  "RoutingAreaNumber",
                  "RPPeerDeviceName",
                  "RPPeerDeviceID",
                  "RPPeerDeviceType",
                  "RPPeerState",
                  "RPPeerUpSince",
                  )



from ..broker import Broker


class SwitchPortMgmtBroker(Broker):
    controller = "switch_port_mgmt"

    def start_poll(self, **kwargs):
        """Start Switch Port Management polling

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` All

             :param type: Parameter to specify type of device list items: DeviceIDs/DeviceGroupsIDs/IPAddresses
             :type type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` []

             :param list: Array of device IDs/device group IDs/IP addresses to be polled
             :type list: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("start_poll"), kwargs)



from ..broker import Broker


class DeviceSendSupportBundlesBroker(Broker):
    controller = "device_send_support_bundles"

    def groups_and_definitions(self, **kwargs):
        """Returns set of Log files groupings and definitions of them

            **Inputs**

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return debug_groups: List of debug group objects
             :rtype debug_groups: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return definitions: List of debug definition objects
             :rtype definitions: Array

            """

        return self.api_request(self._get_method_fullname("groups_and_definitions"), kwargs)

    def support_bundle_statuses(self, **kwargs):
        """Returns set of Support Bundle statuses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: Offset for the Support Bundle statuses to be returned.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param limit: Limit of rows of Support Bundle statuses to be returned.
             :type limit: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return rows: List of support bundle status objects
             :rtype rows: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return total: Total amount of support bundle statuses
             :rtype total: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return updated: Timestamp for last request update
             :rtype updated: DateTime

            """

        return self.api_request(self._get_method_fullname("support_bundle_statuses"), kwargs)

    def create(self, **kwargs):
        """Initiates a Device Support Bundle Request

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param support_case_number: The identifier for Support Bundle Request
             :type support_case_number: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param definitions: Set of debug definitions ids to enable
             :type definitions: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param debug_groups: Set of debug groups ids to enable
             :type debug_groups: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_ip_range: Set of ip addresses for SNMP debugging
             :type snmp_ip_range: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param device_ip_address: The IP address of the device.
             :type device_ip_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` SNMPv2

             :param snmp_version: The SNMP Version.
             :type snmp_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_community_string: The SNMP community string associated with the device.
             :type snmp_community_string: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_oid: The SNMP OID identifier
             :type snmp_oid: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_auth_username: The SNMP username associated with the device. Used only for SNMP Version 3.
             :type snmp_auth_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` md5

             :param snmp_auth_protocol: The SNMP authenticationprotocol associated with the device. Used only for SNMP Version 3.
             :type snmp_auth_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_auth_password: The SNMP authentication password associated with the device. Used only for SNMP Version 3.
             :type snmp_auth_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` aes-128

             :param snmp_privacy_protocol: The SNMP privacy protocol associated with the device. Used only for SNMP Version 3.
             :type snmp_privacy_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param snmp_privacy_password: The SNMP privacy password associated with the device. Used only for SNMP Version 3.
             :type snmp_privacy_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` sftp

             :param delivery_method: The final delivery method of the device Support Bundle Request.
             :type delivery_method: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param notification_email: The email address that used for notifications
             :type notification_email: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param duration_time: Time in hours for how long debugging process will be enabled
             :type duration_time: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The unique identifier for Support Bundle Request initialized
             :rtype id: Integer

            """

        return self.api_request(self._get_method_fullname("create"), kwargs)

    def delete_log_file(self, **kwargs):
        """Delete the Support Bundle log file

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param file_id: The identifier of log filename being deleted
             :type file_id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("delete_log_file"), kwargs)

    def resend_log_file(self, **kwargs):
        """Resend the Support Bundle log file

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param file_id: The identifier of log filename being resent
             :type file_id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("resend_log_file"), kwargs)

    def download_status_log(self, **kwargs):
        """Download log file associated with the Support Bundle status

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param support_case_number: The identifier for Support Bundle Request
             :type support_case_number: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param filename: Name for status log file
             :type filename: String

            **Outputs**

            """

        return self.api_mixed_request(self._get_method_fullname("download_status_log"), kwargs)



from ..remote import RemoteModel


class ExcludedDeviceRemote(RemoteModel):
    """
    Banned devices used by the NetMRI discovery engine.


    |  ``ExclusionID:`` The internal NetMRI identifier for this banned device definition.
    |  ``attribute type:`` number

    |  ``SNMPEngineID:`` The unique identifier of the banned device.
    |  ``attribute type:`` string

    |  ``IPAddress:`` The IP address of the banned device.
    |  ``attribute type:`` string

    |  ``UnitID:`` The internal NetMRI identifier for the collector on which the device is banned.
    |  ``attribute type:`` number

    |  ``LastUpdate:`` The date and time the banned device was added to the exclusion list.
    |  ``attribute type:`` timestamp

    |  ``VirtualNetworkName:`` The name of the Network View.
    |  ``attribute type:`` string

    """

    properties = ("ExclusionID",
                  "SNMPEngineID",
                  "IPAddress",
                  "UnitID",
                  "LastUpdate",
                  "VirtualNetworkName",
                  )



from ..broker import Broker


class DataSourceBroker(Broker):
    controller = "data_sources"

    def index(self, **kwargs):
        """Lists the available data sources. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for this data source.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for this data source.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the data sources as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data source methods. The listed methods will be called on each data source returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DataSourceID

             :param sort: The data field(s) to use for sorting the output. Default is DataSourceID. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataSource. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_sources: An array of the DataSource objects that match the specified input criteria.
             :rtype data_sources: Array of DataSource

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified data source.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for this data source.
             :type DataSourceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data source methods. The listed methods will be called on each data source returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_source: The data source identified by the specified DataSourceID.
             :rtype data_source: DataSource

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available data sources matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type DataSourceChangedCols: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type DataSourceChangedCols: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type DataSourceEndTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type DataSourceEndTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for this data source.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for this data source.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceIPDotted: The IP address of this data source, in dotted notation.
             :type DataSourceIPDotted: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceIPDotted: The IP address of this data source, in dotted notation.
             :type DataSourceIPDotted: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceIPNumeric: The numerical IP address of this data source.
             :type DataSourceIPNumeric: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceIPNumeric: The numerical IP address of this data source.
             :type DataSourceIPNumeric: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceName: The name of this data source.
             :type DataSourceName: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceName: The name of this data source.
             :type DataSourceName: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourcePrivateIPDotted: Another IP address for the data source, in dotted notation.
             :type DataSourcePrivateIPDotted: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourcePrivateIPDotted: Another IP address for the data source, in dotted notation.
             :type DataSourcePrivateIPDotted: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourcePrivateIPNumeric: The numerical version of the alternate IP address.
             :type DataSourcePrivateIPNumeric: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourcePrivateIPNumeric: The numerical version of the alternate IP address.
             :type DataSourcePrivateIPNumeric: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceSerialNo: The serial number of the collector.
             :type DataSourceSerialNo: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceSerialNo: The serial number of the collector.
             :type DataSourceSerialNo: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceStartTime: The starting effective time of this revision of the record.
             :type DataSourceStartTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceStartTime: The starting effective time of this revision of the record.
             :type DataSourceStartTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceTimestamp: The date and time this record was collected or calculated.
             :type DataSourceTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceTimestamp: The date and time this record was collected or calculated.
             :type DataSourceTimestamp: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param Network: The network to which this data source is assigned.
             :type Network: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param Network: The network to which this data source is assigned.
             :type Network: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the data sources as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data source methods. The listed methods will be called on each data source returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DataSourceID

             :param sort: The data field(s) to use for sorting the output. Default is DataSourceID. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataSource. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against data sources, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceChangedCols, DataSourceEndTime, DataSourceID, DataSourceIPDotted, DataSourceIPNumeric, DataSourceName, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo, DataSourceStartTime, DataSourceTimestamp, Network.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_sources: An array of the DataSource objects that match the specified input criteria.
             :rtype data_sources: Array of DataSource

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available data sources matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceChangedCols, DataSourceEndTime, DataSourceID, DataSourceIPDotted, DataSourceIPNumeric, DataSourceName, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo, DataSourceStartTime, DataSourceTimestamp, Network.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceChangedCols: The operator to apply to the field DataSourceChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceChangedCols: If op_DataSourceChangedCols is specified, the field named in this input will be compared to the value in DataSourceChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceChangedCols must be specified if op_DataSourceChangedCols is specified.
             :type val_f_DataSourceChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceChangedCols: If op_DataSourceChangedCols is specified, this value will be compared to the value in DataSourceChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceChangedCols must be specified if op_DataSourceChangedCols is specified.
             :type val_c_DataSourceChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceEndTime: The operator to apply to the field DataSourceEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceEndTime: The ending effective time of this revision of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceEndTime: If op_DataSourceEndTime is specified, the field named in this input will be compared to the value in DataSourceEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceEndTime must be specified if op_DataSourceEndTime is specified.
             :type val_f_DataSourceEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceEndTime: If op_DataSourceEndTime is specified, this value will be compared to the value in DataSourceEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceEndTime must be specified if op_DataSourceEndTime is specified.
             :type val_c_DataSourceEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for this data source. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceIPDotted: The operator to apply to the field DataSourceIPDotted. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceIPDotted: The IP address of this data source, in dotted notation. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceIPDotted: If op_DataSourceIPDotted is specified, the field named in this input will be compared to the value in DataSourceIPDotted using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceIPDotted must be specified if op_DataSourceIPDotted is specified.
             :type val_f_DataSourceIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceIPDotted: If op_DataSourceIPDotted is specified, this value will be compared to the value in DataSourceIPDotted using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceIPDotted must be specified if op_DataSourceIPDotted is specified.
             :type val_c_DataSourceIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceIPNumeric: The operator to apply to the field DataSourceIPNumeric. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceIPNumeric: The numerical IP address of this data source. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceIPNumeric: If op_DataSourceIPNumeric is specified, the field named in this input will be compared to the value in DataSourceIPNumeric using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceIPNumeric must be specified if op_DataSourceIPNumeric is specified.
             :type val_f_DataSourceIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceIPNumeric: If op_DataSourceIPNumeric is specified, this value will be compared to the value in DataSourceIPNumeric using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceIPNumeric must be specified if op_DataSourceIPNumeric is specified.
             :type val_c_DataSourceIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceName: The operator to apply to the field DataSourceName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceName: The name of this data source. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceName: If op_DataSourceName is specified, the field named in this input will be compared to the value in DataSourceName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceName must be specified if op_DataSourceName is specified.
             :type val_f_DataSourceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceName: If op_DataSourceName is specified, this value will be compared to the value in DataSourceName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceName must be specified if op_DataSourceName is specified.
             :type val_c_DataSourceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourcePrivateIPDotted: The operator to apply to the field DataSourcePrivateIPDotted. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourcePrivateIPDotted: Another IP address for the data source, in dotted notation. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourcePrivateIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourcePrivateIPDotted: If op_DataSourcePrivateIPDotted is specified, the field named in this input will be compared to the value in DataSourcePrivateIPDotted using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourcePrivateIPDotted must be specified if op_DataSourcePrivateIPDotted is specified.
             :type val_f_DataSourcePrivateIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourcePrivateIPDotted: If op_DataSourcePrivateIPDotted is specified, this value will be compared to the value in DataSourcePrivateIPDotted using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourcePrivateIPDotted must be specified if op_DataSourcePrivateIPDotted is specified.
             :type val_c_DataSourcePrivateIPDotted: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourcePrivateIPNumeric: The operator to apply to the field DataSourcePrivateIPNumeric. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourcePrivateIPNumeric: The numerical version of the alternate IP address. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourcePrivateIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourcePrivateIPNumeric: If op_DataSourcePrivateIPNumeric is specified, the field named in this input will be compared to the value in DataSourcePrivateIPNumeric using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourcePrivateIPNumeric must be specified if op_DataSourcePrivateIPNumeric is specified.
             :type val_f_DataSourcePrivateIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourcePrivateIPNumeric: If op_DataSourcePrivateIPNumeric is specified, this value will be compared to the value in DataSourcePrivateIPNumeric using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourcePrivateIPNumeric must be specified if op_DataSourcePrivateIPNumeric is specified.
             :type val_c_DataSourcePrivateIPNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceSerialNo: The operator to apply to the field DataSourceSerialNo. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceSerialNo: The serial number of the collector. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceSerialNo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceSerialNo: If op_DataSourceSerialNo is specified, the field named in this input will be compared to the value in DataSourceSerialNo using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceSerialNo must be specified if op_DataSourceSerialNo is specified.
             :type val_f_DataSourceSerialNo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceSerialNo: If op_DataSourceSerialNo is specified, this value will be compared to the value in DataSourceSerialNo using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceSerialNo must be specified if op_DataSourceSerialNo is specified.
             :type val_c_DataSourceSerialNo: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceStartTime: The operator to apply to the field DataSourceStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceStartTime: The starting effective time of this revision of the record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceStartTime: If op_DataSourceStartTime is specified, the field named in this input will be compared to the value in DataSourceStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceStartTime must be specified if op_DataSourceStartTime is specified.
             :type val_f_DataSourceStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceStartTime: If op_DataSourceStartTime is specified, this value will be compared to the value in DataSourceStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceStartTime must be specified if op_DataSourceStartTime is specified.
             :type val_c_DataSourceStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceTimestamp: The operator to apply to the field DataSourceTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceTimestamp: If op_DataSourceTimestamp is specified, the field named in this input will be compared to the value in DataSourceTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceTimestamp must be specified if op_DataSourceTimestamp is specified.
             :type val_f_DataSourceTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceTimestamp: If op_DataSourceTimestamp is specified, this value will be compared to the value in DataSourceTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceTimestamp must be specified if op_DataSourceTimestamp is specified.
             :type val_c_DataSourceTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_Network: The operator to apply to the field Network. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. Network: The network to which this data source is assigned. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_Network: If op_Network is specified, the field named in this input will be compared to the value in Network using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_Network must be specified if op_Network is specified.
             :type val_f_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_Network: If op_Network is specified, this value will be compared to the value in Network using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_Network must be specified if op_Network is specified.
             :type val_c_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the data sources as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of data source methods. The listed methods will be called on each data source returned and included in the output. Available methods are: network_name.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DataSourceID

             :param sort: The data field(s) to use for sorting the output. Default is DataSourceID. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DataSource. Valid values are DataSourceID, DataSourceStartTime, DataSourceEndTime, DataSourceChangedCols, DataSourceTimestamp, Network, DataSourceName, DataSourceIPDotted, DataSourceIPNumeric, DataSourcePrivateIPDotted, DataSourcePrivateIPNumeric, DataSourceSerialNo. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return data_sources: An array of the DataSource objects that match the specified input criteria.
             :rtype data_sources: Array of DataSource

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..broker import Broker


class DiscoveryStatusesBroker(Broker):
    controller = "discovery_statuses"

    def static(self, **kwargs):
        """Displays the current discovery statuses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` current

             :param view: Defined filters for displaying discovery statuses data. Valid values are "current", "licensed", "non_reached", "problems", "ok"
             :type view: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The index of the last row to display. Default value is 25
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: Search string
             :type query: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only. Specifying a UnitID will pull the most recent data from a specific collector while not specifying one will pull data directly from the OC.
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("static"), kwargs)

    def telnet_queue(self, **kwargs):
        """Displays the telnet queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("telnet_queue"), kwargs)

    def ssh_queue(self, **kwargs):
        """Displays the ssh queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("ssh_queue"), kwargs)

    def snmp_queue(self, **kwargs):
        """Displays the snmp queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("snmp_queue"), kwargs)

    def summary(self, **kwargs):
        """Summary data for discovery statuses

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("summary"), kwargs)

    def discover_next(self, **kwargs):
        """Set the given device ids to be discovered next

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: An array of device ids to be discovered next
             :type DeviceIDs: Array

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("discover_next"), kwargs)

    def discover_now(self, **kwargs):
        """Set the "DeviceID" of the given device to be discovered now and check the status of previously started discovery process. If the "id" parameter is not set, the method starts a new Discover Now process and returns its id for further tracking the process status. If the "id" parameter is set, the method returns a chunk of log output of the corresponding discovery process. The number of bytes to read is defined by the "read" parameter.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The id of the previously started discovery process required to retrieve its status
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param DeviceID: ID of the device to re-discover now, if known
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ip_address: Device IP address to be discovered now
             :type ip_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param read: The number of bytes to read from the discover now output
             :type read: Integer

            |  ``api version min:`` 2.1.1
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param ignore_history_ind: If true, NetMRI will not check for previous instances of this IP address, and therefore will not associate this IP address with the associated device history.
             :type ignore_history_ind: Boolean

            |  ``api version min:`` 2.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param mac_address: Device MAC address to be discovered now
             :type mac_address: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("discover_now"), kwargs)

    def abort_discovery(self, **kwargs):
        """Abort an outstanding discover now session

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: ID of the discover now request to abort
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("abort_discovery"), kwargs)

    def override_licenses(self, **kwargs):
        """Overrides a license for all or some devices

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: The list of devices to override licenses
             :type DeviceIDs: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param Licensed: The state of the device license override. Valid values are 0 (unlicensed), 1 (licensed), 2 (automatic)
             :type Licensed: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchPortManagement: The state of the Switch Port Management license override. Valid values are on or off if exists. An empty string is passed if not present.
             :type SwitchPortManagement: String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param AccessProvisioning: The state of the Security Device Controller license override. Valid values are on or off if exists. An empty string is passed if not present.
             :type AccessProvisioning: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("override_licenses"), kwargs)

    def unmanage(self, **kwargs):
        """Set one or more specified devices to unmanaged

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: The list of devices to set to unmanaged
             :type DeviceIDs: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("unmanage"), kwargs)

    def update_snmp(self, **kwargs):
        """Update the SNMP read credential for a device

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to be updated
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param SNMPVersion: The SNMP Version
             :type SNMPVersion: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPRead: The SNMP read community
             :type SNMPRead: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPAuthPW: The SNMP auth password for SNMPv3
             :type SNMPAuthPW: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPAuthProto: The SNMP auth protocol for SNMPv3
             :type SNMPAuthProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPPrivPW: The SNMP priv password for SNMPv3
             :type SNMPPrivPW: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPPrivProto: The SNMP priv protocol for SNMPv3
             :type SNMPPrivProto: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("update_snmp"), kwargs)

    def update_cli_credentials(self, **kwargs):
        """Update the CLI credential for a device

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to be updated
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.SSH.Username: SSH username
             :type config.SSH.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.SSH.Password: SSH password
             :type config.SSH.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.Telnet.Username: Telnet username
             :type config.Telnet.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.Telnet.Password: Telnet password
             :type config.Telnet.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.HTTP.Username: HTTP username
             :type config.HTTP.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.HTTP.Password: HTTP password
             :type config.HTTP.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.EnablePassword: Enable password
             :type config.EnablePassword: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("update_cli_credentials"), kwargs)

    def cli_guesses(self, **kwargs):
        """Displays the status of all devices CLI guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("cli_guesses"), kwargs)

    def snmp_guesses(self, **kwargs):
        """Displays the status of all devices SNMP guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("snmp_guesses"), kwargs)

    def show_opsec_certificate(self, **kwargs):
        """Return OPSEC device certificate

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("show_opsec_certificate"), kwargs)

    def opsec_guesses(self, **kwargs):
        """Displays the status of all devices OPSEC guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("opsec_guesses"), kwargs)

    def status_management(self, **kwargs):
        """Returns a list of discovery statuses of the device with given id

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to get management status
             :type DeviceID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("status_management"), kwargs)

    def setup_summary(self, **kwargs):
        """Discovery Wizard setup summary information

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("setup_summary"), kwargs)
